@@ -3,7 +3,7 @@
  * @brief Implements the LfoWidget GUI class.
  *
  *
- *      Copyright 2009 - 2023 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2026 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -45,8 +45,7 @@ LfoWidget::LfoWidget(MidiLfo *p_midiLfo, GlobStore *p_globStore,
     bool compactStyle = p_prefs->compactStyle;
 #else
 LfoWidget::LfoWidget():
-    ModuleWidget("LFO:"),
-    midiLfo(NULL)
+    ModuleWidget("LFO:")
 {
     bool compactStyle = true;
 #endif
@@ -203,7 +202,7 @@ LfoWidget::LfoWidget():
     sliderLayout->addStretch();
     if (compactStyle) {
         sliderLayout->setSpacing(1);
-        sliderLayout->setMargin(2);
+        sliderLayout->setContentsMargins(2, 2, 2, 2);
     }
 
     QGridLayout *paramBoxLayout = new QGridLayout;
@@ -225,7 +224,7 @@ LfoWidget::LfoWidget():
 
     if (compactStyle) {
         paramBoxLayout->setSpacing(1);
-        paramBoxLayout->setMargin(2);
+        paramBoxLayout->setContentsMargins(2, 2, 2, 2);
     }
 
     QGridLayout* waveBoxLayout = new QGridLayout;
@@ -235,7 +234,7 @@ LfoWidget::LfoWidget():
     waveBoxLayout->addLayout(sliderLayout, 3, 0);
     if (compactStyle) {
         waveBoxLayout->setSpacing(0);
-        waveBoxLayout->setMargin(2);
+        waveBoxLayout->setContentsMargins(2, 2, 2, 2);
     }
     waveBox->setLayout(waveBoxLayout);
 
@@ -327,24 +326,24 @@ void LfoWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
             }
         }
 
-        if (xml.isStartElement() && (xml.name() == "waveParams")) {
+        if (xml.isStartElement() && (xml.name() == QString("waveParams"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.name() == "loopmode") {
+                if (xml.name() == QString("loopmode")) {
                     tmp = xml.readElementText().toInt();
                     loopBox->setCurrentIndex(tmp);
                     updateLoop(tmp);
                 }
-                else if (xml.name() == "waveform")
+                else if (xml.name() == QString("waveform"))
                     wvtmp = xml.readElementText().toInt();
-                else if (xml.name() == "frequency") {
+                else if (xml.name() == QString("frequency")) {
                     tmp = xml.readElementText().toInt();
                     freqBox->setCurrentIndex(tmp);
                     updateFreq(tmp);
                 }
-                else if (xml.name() == "resolution") {
+                else if (xml.name() == QString("resolution")) {
                     tmp = xml.readElementText().toInt();
                     if (qmaxVersion == "" && tmp < 9) {
                         tmp = mapOldLfoRes[tmp];
@@ -352,7 +351,7 @@ void LfoWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                     resBox->setCurrentIndex(tmp);
                     updateRes(tmp);
                 }
-                else if (xml.name() == "size") {
+                else if (xml.name() == QString("size")) {
                     tmp = xml.readElementText().toInt();
                     if (qmaxVersion == "" && tmp < 12) {
                         tmp = mapOldLfoSize[tmp];
@@ -360,42 +359,42 @@ void LfoWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                     sizeBox->setCurrentIndex(tmp);
                     updateSize(tmp);
                 }
-                else if (xml.name() == "amplitude")
+                else if (xml.name() == QString("amplitude"))
                     amplitude->setValue(xml.readElementText().toInt());
-                else if (xml.name() == "offset")
+                else if (xml.name() == QString("offset"))
                     offset->setValue(xml.readElementText().toInt());
-                else if (xml.name() == "phase")
+                else if (xml.name() == QString("phase"))
                     phase->setValue(xml.readElementText().toInt());
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "muteMask")) {
+        else if (xml.isStartElement() && (xml.name() == QString("muteMask"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.isStartElement() && (xml.name() == "data")) {
+                if (xml.isStartElement() && (xml.name() == QString("data"))) {
                     QByteArray tmpArray =
                             QByteArray::fromHex(xml.readElementText().toLatin1());
-                    for (int l1 = 0; l1 < tmpArray.count(); l1++) {
+                    for (int l1 = 0; l1 < tmpArray.length(); l1++) {
                         midiLfo->muteMask[l1] = tmpArray.at(l1);
                     }
-                    midiLfo->maxNPoints = tmpArray.count();
+                    midiLfo->maxNPoints = tmpArray.length();
                 }
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "customWave")) {
+        else if (xml.isStartElement() && (xml.name() == QString("customWave"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.isStartElement() && (xml.name() == "data")) {
+                if (xml.isStartElement() && (xml.name() == QString("data"))) {
                     QByteArray tmpArray =
                             QByteArray::fromHex(xml.readElementText().toLatin1());
                     int step = TPQN / midiLfo->res;
                     int lt = 0;
-                    for (int l1 = 0; l1 < tmpArray.count(); l1++) {
+                    for (int l1 = 0; l1 < tmpArray.length(); l1++) {
                         sample.value = tmpArray.at(l1);
                         sample.tick = lt;
                         sample.muted = midiLfo->muteMask[l1];
@@ -428,23 +427,24 @@ void LfoWidget::loadWaveForms()
 void LfoWidget::updateWaveForm(int val)
 {
     if (val > 5) return;
+    bool isCustom = (val == 5);
     waveFormBoxIndex = val;
-    if (midiLfo) midiLfo->updateWaveForm(val);
+    amplitude->setDisabled(isCustom);
+    freqBox->setDisabled(isCustom);
+    phase->setDisabled(isCustom);
+    modified = true;
+#ifdef APPBUILD
+    midiLfo->updateWaveForm(val);
     std::vector<Sample> sdata;
-    if (midiLfo) midiLfo->getData(&sdata);
+    midiLfo->getData(&sdata);
 #if QT_VERSION <= QT_VERSION_CHECK(5,14,0)
     data=QVector<Sample>::fromStdVector(sdata);
 #else
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
-    if (midiLfo) screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
-    bool isCustom = (val == 5);
-    if (isCustom && midiLfo) midiLfo->newCustomOffset();
-    amplitude->setDisabled(isCustom);
-    freqBox->setDisabled(isCustom);
-    phase->setDisabled(isCustom);
-    modified = true;
-
+    screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+    if (isCustom) midiLfo->newCustomOffset();
+#endif
 }
 
 void LfoWidget::updateFreq(int val)
@@ -452,7 +452,7 @@ void LfoWidget::updateFreq(int val)
     if ((uint64_t)val >= sizeof(lfoFreqValues)/sizeof(lfoFreqValues[0])) return;
     freqBoxIndex = val;
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updateFrequency(lfoFreqValues[val]);
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -462,6 +462,7 @@ void LfoWidget::updateFreq(int val)
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+#endif
 }
 
 void LfoWidget::updateRes(int val)
@@ -469,7 +470,7 @@ void LfoWidget::updateRes(int val)
     if ((uint64_t)val >= sizeof(lfoResValues)/sizeof(lfoResValues[0])) return;
     resBoxIndex = val;
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updateResolution(lfoResValues[val]);
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -480,6 +481,7 @@ void LfoWidget::updateRes(int val)
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
     if (waveFormBoxIndex == 5) midiLfo->newCustomOffset();
+#endif
 }
 
 void LfoWidget::updateSize(int val)
@@ -487,7 +489,7 @@ void LfoWidget::updateSize(int val)
     if ((uint64_t)val >= sizeof(lfoSizeValues)/sizeof(lfoSizeValues[0])) return;
     sizeBoxIndex = val;
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updateSize(sizeBox->currentText().toInt());
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -498,19 +500,22 @@ void LfoWidget::updateSize(int val)
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
     if (waveFormBoxIndex == 5) midiLfo->newCustomOffset();
+#endif
 }
 
 void LfoWidget::updateLoop(int val)
 {
     if (val > 6) return;
-    if (midiLfo) midiLfo->updateLoop(val);
+#ifdef APPBUILD
+    midiLfo->updateLoop(val);
+#endif
     modified = true;
 }
 
 void LfoWidget::updateAmp(int val)
 {
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updateAmplitude(val);
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -520,12 +525,15 @@ void LfoWidget::updateAmp(int val)
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+#else
+    (void)val;
+#endif
 }
 
 void LfoWidget::updateOffs(int val)
 {
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updateOffset(val);
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -535,12 +543,16 @@ void LfoWidget::updateOffs(int val)
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+#else
+    (void)val;
+#endif
+
 }
 
 void LfoWidget::updatePhase(int val)
 {
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     midiLfo->updatePhase(val);
     std::vector<Sample> sdata;
     midiLfo->getData(&sdata);
@@ -550,11 +562,16 @@ void LfoWidget::updatePhase(int val)
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+#else
+    (void)val;
+#endif
 }
 
 void LfoWidget::copyToCustom()
 {
-    if (midiLfo) midiLfo->copyToCustom();
+#ifdef APPBUILD
+    midiLfo->copyToCustom();
+#endif
     waveFormBox->setCurrentIndex(5);
     updateWaveForm(5);
     modified = true;
@@ -563,7 +580,7 @@ void LfoWidget::copyToCustom()
 void LfoWidget::updateFlipWaveVertical()
 {
     modified = true;
-    if (!midiLfo) return;
+#ifdef APPBUILD
     if (waveFormBox->currentIndex() != 5) copyToCustom();
     midiLfo->flipWaveVertical();
     std::vector<Sample> sdata;
@@ -574,13 +591,16 @@ void LfoWidget::updateFlipWaveVertical()
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data.mid(0, midiLfo->res * midiLfo->size + 1));
+#endif
 }
 
 void LfoWidget::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
 {
-    if (!midiLfo) emit mouseSig(mouseX, mouseY, buttons, pressed);
-    else midiLfo->mouseEvent(mouseX, mouseY, buttons, pressed);
-
+#ifdef APPBUILD
+    midiLfo->mouseEvent(mouseX, mouseY, buttons, pressed);
+#else
+    emit mouseSig(mouseX, mouseY, buttons, pressed);
+#endif
     if ((buttons == 1) && (waveFormBox->currentIndex() != 5)) {
         waveFormBox->setCurrentIndex(5);
         updateWaveForm(5);
@@ -598,10 +618,13 @@ void LfoWidget::mouseWheel(int step)
 
 void LfoWidget::setRecord(bool on)
 {
-    if (midiLfo) midiLfo->setRecordMode(on);
+#ifdef APPBUILD
+    midiLfo->setRecordMode(on);
+#endif
     screen->setRecordMode(on);
 }
 
+#ifdef APPBUILD
 QVector<Sample> LfoWidget::getCustomWave()
 {
 #if QT_VERSION <= QT_VERSION_CHECK(5,14,0)
@@ -620,7 +643,6 @@ QVector<bool> LfoWidget::getMuteMask()
 #endif
 }
 
-#ifdef APPBUILD
 
 void LfoWidget::doStoreParams(int ix)
 {
@@ -635,8 +657,8 @@ void LfoWidget::doStoreParams(int ix)
     parStore->temp.phase = phase->value();
     parStore->temp.waveForm = waveFormBox->currentIndex();
 
-    if (midiLfo) parStore->temp.wave = getCustomWave().mid(0, midiLfo->maxNPoints);
-    if (midiLfo) parStore->temp.muteMask = getMuteMask().mid(0, midiLfo->maxNPoints);
+    parStore->temp.wave = getCustomWave().mid(0, midiLfo->maxNPoints);
+    parStore->temp.muteMask = getMuteMask().mid(0, midiLfo->maxNPoints);
 
     parStore->tempToList(ix);
 }
